@@ -26,18 +26,13 @@ class AsyncMockLink(AsyncTerminatingLink):
         query_resolver: Union[AsyncMockResolver, dict] = None,
         mutation_resolver: Union[AsyncMockResolver, dict] = None,
         subscription_resolver: Union[AsyncMockResolver, dict] = None,
-        schema: GraphQLSchema = None,
     ) -> None:
         self.query_resolver = query_resolver or resolver
         self.mutation_resolver = mutation_resolver or resolver
         self.subscription_resolver = subscription_resolver or resolver
-        self.schema = schema
 
     async def aquery(self, operation: Operation) -> GraphQLResult:
 
-        if self.schema is not None:
-            validate(self.schema, operation.document_node)
-
         if operation.node.operation == OperationType.QUERY:
             futures = []
 
