@@ -47,7 +47,6 @@ class AsyncStatefulMockLink(AsyncTerminatingLink):
         self.connection_task.cancel()
 
         try:
-            print("Disconnecting")
             await self.connection_task
         except asyncio.CancelledError:
             pass
@@ -98,13 +97,11 @@ class AsyncStatefulMockLink(AsyncTerminatingLink):
             self._inqueue.task_done()
 
     async def submit(self, o, id):
-        self._inqueue.put_nowait((o, id))
+        await self._inqueue.put((o, id))
 
     async def aquery(self, operation: Operation) -> GraphQLResult:
         if self.connected == False:
-            raise LinkNotConnectedError(
-                "This is a async Terminating Link, that needs to be connected before. In an async context, preferably use an async context manager. In sync call connect before."
-            )
+            raise LinkNotConnectedError("AsyncMockLink is not connected")
 
         uniqueid = uuid.uuid4()
         self.futures[uniqueid] = asyncio.Future()
@@ -112,7 +109,22 @@ class AsyncStatefulMockLink(AsyncTerminatingLink):
         return await self.futures[uniqueid]
 
     async def asubscribe(self, operation: Operation) -> AsyncIterator[GraphQLResult]:
-        assert NotImplementedError("This is not implemented for now")
+        if operation.node.operation == OperationType.SUBSCRIPTION:
+            futures = []
+            assert (
+                len(operation.node.selection_set.selections) == 1
+            ), "Only one Subscription at a time possible"
+
+            op = operation.node.selection_set.selections[0]
+            assert (
+                op.name.value in self.subscription_resolver
+            ), f"Mocked Resolver for Subscription {op.name.value} not in resolver: {self.subscription_resolver} for AsyncMockLink"
+
+            async for event in self.subscription_resolver[op.name.value](operation):
+                yield GraphQLResult(data={target_from_node(op): event})
+
+        else:
+            raise NotImplementedError("Only subscription are mocked")
 
     def query(self, operation: Operation) -> GraphQLResult:
         raise NotImplementedError("This is a async Terminating Link")
